@@ -1,5 +1,5 @@
 /* gc-gnulib.c --- Common gnulib internal crypto interface functions
- * Copyright (C) 2002-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2021 Free Software Foundation, Inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this file; if not, see <http://www.gnu.org/licenses/>.
+ * along with this file; if not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,183 +27,108 @@
 #include <string.h>
 
 /* For randomize. */
-#ifdef GNULIB_GC_RANDOM
-# include <unistd.h>
-# include <sys/types.h>
-# include <sys/stat.h>
-# include <fcntl.h>
-# include <errno.h>
+#if GNULIB_GC_RANDOM
+#include <unistd.h>
+#include <errno.h>
+#include <sys/random.h>
 #endif
 
 /* Hashes. */
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
 # include "md2.h"
 #endif
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
 # include "md4.h"
 #endif
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
 # include "md5.h"
 #endif
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
 # include "sha1.h"
 #endif
-#if defined(GNULIB_GC_HMAC_MD5) || defined(GNULIB_GC_HMAC_SHA1) || defined(GNULIB_GC_HMAC_SHA256) || defined(GNULIB_GC_HMAC_SHA512)
+#if GNULIB_GC_SHA256
+# include "sha256.h"
+#endif
+#if GNULIB_GC_SHA512
+# include "sha512.h"
+#endif
+#if GNULIB_GC_SM3
+# include "sm3.h"
+#endif
+#if GNULIB_GC_HMAC_MD5 || GNULIB_GC_HMAC_SHA1 || GNULIB_GC_HMAC_SHA256 || GNULIB_GC_HMAC_SHA512
 # include "hmac.h"
 #endif
 
 /* Ciphers. */
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
 # include "arcfour.h"
 #endif
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
 # include "arctwo.h"
 #endif
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
 # include "des.h"
 #endif
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
 # include "rijndael-api-fst.h"
 #endif
 
-#ifdef GNULIB_GC_RANDOM
-# if (defined _WIN32 || defined __WIN32__) && ! defined __CYGWIN__
-#  include <windows.h>
-#  include <wincrypt.h>
-HCRYPTPROV g_hProv = 0;
-#  ifndef PROV_INTEL_SEC
-#   define PROV_INTEL_SEC 22
-#  endif
-#  ifndef CRYPT_VERIFY_CONTEXT
-#   define CRYPT_VERIFY_CONTEXT 0xF0000000
-#  endif
-# endif
-#endif
-
 Gc_rc
 gc_init (void)
 {
-#ifdef GNULIB_GC_RANDOM
-# if (defined _WIN32 || defined __WIN32__) && ! defined __CYGWIN__
-  if (g_hProv)
-    CryptReleaseContext (g_hProv, 0);
-
-  /* There is no need to create a container for just random data, so
-     we can use CRYPT_VERIFY_CONTEXT (one call) see:
-     http://blogs.msdn.com/dangriff/archive/2003/11/19/51709.aspx */
-
-  /* We first try to use the Intel PIII RNG if drivers are present */
-  if (!CryptAcquireContext (&g_hProv, NULL, NULL,
-                            PROV_INTEL_SEC, CRYPT_VERIFY_CONTEXT))
-    {
-      /* not a PIII or no drivers available, use default RSA CSP */
-      if (!CryptAcquireContext (&g_hProv, NULL, NULL,
-                                PROV_RSA_FULL, CRYPT_VERIFY_CONTEXT))
-        return GC_RANDOM_ERROR;
-    }
-# endif
-#endif
-
   return GC_OK;
 }
 
 void
 gc_done (void)
 {
-#ifdef GNULIB_GC_RANDOM
-# if (defined _WIN32 || defined __WIN32__) && ! defined __CYGWIN__
-  if (g_hProv)
-    {
-      CryptReleaseContext (g_hProv, 0);
-      g_hProv = 0;
-    }
-# endif
-#endif
-
   return;
 }
 
-#ifdef GNULIB_GC_RANDOM
+#if GNULIB_GC_RANDOM
 
-/* Randomness. */
-
-static Gc_rc
-randomize (int level, char *data, size_t datalen)
+/* Overwrite BUFFER with random data, under the control of getrandom
+   FLAGS.  BUFFER contains LENGTH bytes.  Inspired by getentropy,
+   however LENGTH is not restricted to 256.  Return 0 on success, -1
+   (setting errno) on failure.  */
+static int
+randomize (void *buffer, size_t length, unsigned int flags)
 {
-#if (defined _WIN32 || defined __WIN32__) && ! defined __CYGWIN__
-  if (!g_hProv)
-    return GC_RANDOM_ERROR;
-  CryptGenRandom (g_hProv, (DWORD) datalen, data);
-#else
-  int fd;
-  const char *device;
-  size_t len = 0;
-  int rc;
+  char *buf = buffer;
 
-  switch (level)
+  for (;;)
     {
-    case 0:
-      device = NAME_OF_NONCE_DEVICE;
-      break;
-
-    case 1:
-      device = NAME_OF_PSEUDO_RANDOM_DEVICE;
-      break;
-
-    default:
-      device = NAME_OF_RANDOM_DEVICE;
-      break;
-    }
-
-  if (strcmp (device, "no") == 0)
-    return GC_RANDOM_ERROR;
-
-  fd = open (device, O_RDONLY);
-  if (fd < 0)
-    return GC_RANDOM_ERROR;
-
-  do
-    {
-      ssize_t tmp;
-
-      tmp = read (fd, data, datalen);
-
-      if (tmp < 0)
-        {
-          int save_errno = errno;
-          close (fd);
-          errno = save_errno;
+      ssize_t bytes;
+      if (length == 0)
+        return GC_OK;
+      while ((bytes = getrandom (buf, length, flags)) < 0)
+        if (errno != EINTR)
           return GC_RANDOM_ERROR;
-        }
-
-      len += tmp;
+      if (bytes == 0)
+        break;
+      buf += bytes;
+      length -= bytes;
     }
-  while (len < datalen);
 
-  rc = close (fd);
-  if (rc < 0)
-    return GC_RANDOM_ERROR;
-#endif
-
-  return GC_OK;
+  return GC_RANDOM_ERROR;
 }
 
 Gc_rc
 gc_nonce (char *data, size_t datalen)
 {
-  return randomize (0, data, datalen);
+  return randomize (data, datalen, 0);
 }
 
 Gc_rc
 gc_pseudo_random (char *data, size_t datalen)
 {
-  return randomize (1, data, datalen);
+  return randomize (data, datalen, 0);
 }
 
 Gc_rc
 gc_random (char *data, size_t datalen)
 {
-  return randomize (2, data, datalen);
+  return randomize (data, datalen, GRND_RANDOM);
 }
 
 #endif
@@ -225,17 +150,17 @@ typedef struct _gc_cipher_ctx
 {
   Gc_cipher alg;
   Gc_cipher_mode mode;
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
   arctwo_context arctwoContext;
   char arctwoIV[ARCTWO_BLOCK_SIZE];
 #endif
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
   arcfour_context arcfourContext;
 #endif
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
   gl_des_ctx desContext;
 #endif
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
   rijndaelKeyInstance aesEncKey;
   rijndaelKeyInstance aesDecKey;
   rijndaelCipherInstance aesContext;
@@ -258,7 +183,7 @@ gc_cipher_open (Gc_cipher alg, Gc_cipher_mode mode,
 
   switch (alg)
     {
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
     case GC_ARCTWO40:
       switch (mode)
         {
@@ -272,7 +197,7 @@ gc_cipher_open (Gc_cipher alg, Gc_cipher_mode mode,
       break;
 #endif
 
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
     case GC_ARCFOUR128:
     case GC_ARCFOUR40:
       switch (mode)
@@ -286,7 +211,7 @@ gc_cipher_open (Gc_cipher alg, Gc_cipher_mode mode,
       break;
 #endif
 
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
     case GC_DES:
       switch (mode)
         {
@@ -299,7 +224,7 @@ gc_cipher_open (Gc_cipher alg, Gc_cipher_mode mode,
       break;
 #endif
 
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
     case GC_AES128:
     case GC_AES192:
     case GC_AES256:
@@ -334,20 +259,20 @@ gc_cipher_setkey (gc_cipher_handle handle, size_t keylen, const char *key)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
     case GC_ARCTWO40:
       arctwo_setkey (&ctx->arctwoContext, keylen, key);
       break;
 #endif
 
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
     case GC_ARCFOUR128:
     case GC_ARCFOUR40:
       arcfour_setkey (&ctx->arcfourContext, key, keylen);
       break;
 #endif
 
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
     case GC_DES:
       if (keylen != 8)
         return GC_INVALID_CIPHER;
@@ -355,7 +280,7 @@ gc_cipher_setkey (gc_cipher_handle handle, size_t keylen, const char *key)
       break;
 #endif
 
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
     case GC_AES128:
     case GC_AES192:
     case GC_AES256:
@@ -398,7 +323,7 @@ gc_cipher_setiv (gc_cipher_handle handle, size_t ivlen, const char *iv)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
     case GC_ARCTWO40:
       if (ivlen != ARCTWO_BLOCK_SIZE)
         return GC_INVALID_CIPHER;
@@ -406,7 +331,7 @@ gc_cipher_setiv (gc_cipher_handle handle, size_t ivlen, const char *iv)
       break;
 #endif
 
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
     case GC_AES128:
     case GC_AES192:
     case GC_AES256:
@@ -452,7 +377,7 @@ gc_cipher_encrypt_inline (gc_cipher_handle handle, size_t len, char *data)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
     case GC_ARCTWO40:
       switch (ctx->mode)
         {
@@ -479,21 +404,21 @@ gc_cipher_encrypt_inline (gc_cipher_handle handle, size_t len, char *data)
       break;
 #endif
 
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
     case GC_ARCFOUR128:
     case GC_ARCFOUR40:
       arcfour_stream (&ctx->arcfourContext, data, data, len);
       break;
 #endif
 
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
     case GC_DES:
       for (; len >= 8; len -= 8, data += 8)
         gl_des_ecb_encrypt (&ctx->desContext, data, data);
       break;
 #endif
 
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
     case GC_AES128:
     case GC_AES192:
     case GC_AES256:
@@ -522,7 +447,7 @@ gc_cipher_decrypt_inline (gc_cipher_handle handle, size_t len, char *data)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_ARCTWO
+#if GNULIB_GC_ARCTWO
     case GC_ARCTWO40:
       switch (ctx->mode)
         {
@@ -551,21 +476,21 @@ gc_cipher_decrypt_inline (gc_cipher_handle handle, size_t len, char *data)
       break;
 #endif
 
-#ifdef GNULIB_GC_ARCFOUR
+#if GNULIB_GC_ARCFOUR
     case GC_ARCFOUR128:
     case GC_ARCFOUR40:
       arcfour_stream (&ctx->arcfourContext, data, data, len);
       break;
 #endif
 
-#ifdef GNULIB_GC_DES
+#if GNULIB_GC_DES
     case GC_DES:
       for (; len >= 8; len -= 8, data += 8)
         gl_des_ecb_decrypt (&ctx->desContext, data, data);
       break;
 #endif
 
-#ifdef GNULIB_GC_RIJNDAEL
+#if GNULIB_GC_RIJNDAEL
     case GC_AES128:
     case GC_AES192:
     case GC_AES256:
@@ -599,25 +524,34 @@ gc_cipher_close (gc_cipher_handle handle)
 
 /* Hashes. */
 
-#define MAX_DIGEST_SIZE 20
+#define MAX_DIGEST_SIZE 64
 
 typedef struct _gc_hash_ctx
 {
   Gc_hash alg;
   Gc_hash_mode mode;
   char hash[MAX_DIGEST_SIZE];
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
   struct md2_ctx md2Context;
 #endif
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
   struct md4_ctx md4Context;
 #endif
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
   struct md5_ctx md5Context;
 #endif
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
   struct sha1_ctx sha1Context;
 #endif
+#if GNULIB_GC_SHA256
+  struct sha256_ctx sha256Context;
+#endif
+#if GNULIB_GC_SHA512
+  struct sha512_ctx sha512Context;
+#endif
+#if GNULIB_GC_SM3
+  struct sm3_ctx sm3Context;
+#endif
 } _gc_hash_ctx;
 
 Gc_rc
@@ -638,30 +572,49 @@ gc_hash_open (Gc_hash hash, Gc_hash_mode mode, gc_hash_handle * outhandle)
 
   switch (hash)
     {
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
     case GC_MD2:
-      md2_init_ctx (&ctx->md2Context);
+      /* Not needed, because ctx is already zero-initialized.  */
+      /*md2_init_ctx (&ctx->md2Context);*/
       break;
 #endif
 
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
     case GC_MD4:
       md4_init_ctx (&ctx->md4Context);
       break;
 #endif
 
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
     case GC_MD5:
       md5_init_ctx (&ctx->md5Context);
       break;
 #endif
 
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
     case GC_SHA1:
       sha1_init_ctx (&ctx->sha1Context);
       break;
 #endif
 
+#if GNULIB_GC_SHA256
+    case GC_SHA256:
+      sha256_init_ctx (&ctx->sha256Context);
+      break;
+#endif
+
+#if GNULIB_GC_SHA512
+    case GC_SHA512:
+      sha512_init_ctx (&ctx->sha512Context);
+      break;
+#endif
+
+#if GNULIB_GC_SM3
+    case GC_SM3:
+      sm3_init_ctx (&ctx->sm3Context);
+      break;
+#endif
+
     default:
       rc = GC_INVALID_HASH;
       break;
@@ -717,6 +670,18 @@ gc_hash_digest_length (Gc_hash hash)
       len = GC_SHA1_DIGEST_SIZE;
       break;
 
+    case GC_SHA256:
+      len = GC_SHA256_DIGEST_SIZE;
+      break;
+
+    case GC_SHA512:
+      len = GC_SHA512_DIGEST_SIZE;
+      break;
+
+    case GC_SM3:
+      len = GC_SM3_DIGEST_SIZE;
+      break;
+
     default:
       return 0;
     }
@@ -731,30 +696,48 @@ gc_hash_write (gc_hash_handle handle, size_t len, const char *data)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
     case GC_MD2:
       md2_process_bytes (data, len, &ctx->md2Context);
       break;
 #endif
 
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
     case GC_MD4:
       md4_process_bytes (data, len, &ctx->md4Context);
       break;
 #endif
 
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
     case GC_MD5:
       md5_process_bytes (data, len, &ctx->md5Context);
       break;
 #endif
 
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
     case GC_SHA1:
       sha1_process_bytes (data, len, &ctx->sha1Context);
       break;
 #endif
 
+#if GNULIB_GC_SHA256
+    case GC_SHA256:
+      sha256_process_bytes (data, len, &ctx->sha256Context);
+      break;
+#endif
+
+#if GNULIB_GC_SHA512
+    case GC_SHA512:
+      sha512_process_bytes (data, len, &ctx->sha512Context);
+      break;
+#endif
+
+#if GNULIB_GC_SM3
+    case GC_SM3:
+      sm3_process_bytes (data, len, &ctx->sm3Context);
+      break;
+#endif
+
     default:
       break;
     }
@@ -768,34 +751,55 @@ gc_hash_read (gc_hash_handle handle)
 
   switch (ctx->alg)
     {
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
     case GC_MD2:
       md2_finish_ctx (&ctx->md2Context, ctx->hash);
       ret = ctx->hash;
       break;
 #endif
 
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
     case GC_MD4:
       md4_finish_ctx (&ctx->md4Context, ctx->hash);
       ret = ctx->hash;
       break;
 #endif
 
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
     case GC_MD5:
       md5_finish_ctx (&ctx->md5Context, ctx->hash);
       ret = ctx->hash;
       break;
 #endif
 
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
     case GC_SHA1:
       sha1_finish_ctx (&ctx->sha1Context, ctx->hash);
       ret = ctx->hash;
       break;
 #endif
 
+#if GNULIB_GC_SHA256
+    case GC_SHA256:
+      sha256_finish_ctx (&ctx->sha256Context, ctx->hash);
+      ret = ctx->hash;
+      break;
+#endif
+
+#if GNULIB_GC_SHA512
+    case GC_SHA512:
+      sha512_finish_ctx (&ctx->sha512Context, ctx->hash);
+      ret = ctx->hash;
+      break;
+#endif
+
+#if GNULIB_GC_SM3
+    case GC_SM3:
+      sm3_finish_ctx (&ctx->sm3Context, ctx->hash);
+      ret = ctx->hash;
+      break;
+#endif
+
     default:
       return NULL;
     }
@@ -816,30 +820,48 @@ gc_hash_buffer (Gc_hash hash, const void *in, size_t inlen, char *resbuf)
 {
   switch (hash)
     {
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
     case GC_MD2:
       md2_buffer (in, inlen, resbuf);
       break;
 #endif
 
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
     case GC_MD4:
       md4_buffer (in, inlen, resbuf);
       break;
 #endif
 
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
     case GC_MD5:
       md5_buffer (in, inlen, resbuf);
       break;
 #endif
 
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
     case GC_SHA1:
       sha1_buffer (in, inlen, resbuf);
       break;
 #endif
 
+#if GNULIB_GC_SHA256
+    case GC_SHA256:
+      sha256_buffer (in, inlen, resbuf);
+      break;
+#endif
+
+#if GNULIB_GC_SHA512
+    case GC_SHA512:
+      sha512_buffer (in, inlen, resbuf);
+      break;
+#endif
+
+#if GNULIB_GC_SM3
+    case GC_SM3:
+      sm3_buffer (in, inlen, resbuf);
+      break;
+#endif
+
     default:
       return GC_INVALID_HASH;
     }
@@ -847,7 +869,7 @@ gc_hash_buffer (Gc_hash hash, const void *in, size_t inlen, char *resbuf)
   return GC_OK;
 }
 
-#ifdef GNULIB_GC_MD2
+#if GNULIB_GC_MD2
 Gc_rc
 gc_md2 (const void *in, size_t inlen, void *resbuf)
 {
@@ -856,7 +878,7 @@ gc_md2 (const void *in, size_t inlen, void *resbuf)
 }
 #endif
 
-#ifdef GNULIB_GC_MD4
+#if GNULIB_GC_MD4
 Gc_rc
 gc_md4 (const void *in, size_t inlen, void *resbuf)
 {
@@ -865,7 +887,7 @@ gc_md4 (const void *in, size_t inlen, void *resbuf)
 }
 #endif
 
-#ifdef GNULIB_GC_MD5
+#if GNULIB_GC_MD5
 Gc_rc
 gc_md5 (const void *in, size_t inlen, void *resbuf)
 {
@@ -874,7 +896,7 @@ gc_md5 (const void *in, size_t inlen, void *resbuf)
 }
 #endif
 
-#ifdef GNULIB_GC_SHA1
+#if GNULIB_GC_SHA1
 Gc_rc
 gc_sha1 (const void *in, size_t inlen, void *resbuf)
 {
@@ -883,7 +905,34 @@ gc_sha1 (const void *in, size_t inlen, void *resbuf)
 }
 #endif
 
-#ifdef GNULIB_GC_HMAC_MD5
+#if GNULIB_GC_SHA256
+Gc_rc
+gc_sha256 (const void *in, size_t inlen, void *resbuf)
+{
+  sha256_buffer (in, inlen, resbuf);
+  return GC_OK;
+}
+#endif
+
+#if GNULIB_GC_SHA512
+Gc_rc
+gc_sha512 (const void *in, size_t inlen, void *resbuf)
+{
+  sha512_buffer (in, inlen, resbuf);
+  return GC_OK;
+}
+#endif
+
+#if GNULIB_GC_SM3
+Gc_rc
+gc_sm3 (const void *in, size_t inlen, void *resbuf)
+{
+  sm3_buffer (in, inlen, resbuf);
+  return GC_OK;
+}
+#endif
+
+#if GNULIB_GC_HMAC_MD5
 Gc_rc
 gc_hmac_md5 (const void *key, size_t keylen,
              const void *in, size_t inlen, char *resbuf)
@@ -893,7 +942,7 @@ gc_hmac_md5 (const void *key, size_t keylen,
 }
 #endif
 
-#ifdef GNULIB_GC_HMAC_SHA1
+#if GNULIB_GC_HMAC_SHA1
 Gc_rc
 gc_hmac_sha1 (const void *key, size_t keylen,
               const void *in, size_t inlen, char *resbuf)
@@ -903,7 +952,7 @@ gc_hmac_sha1 (const void *key, size_t keylen,
 }
 #endif
 
-#ifdef GNULIB_GC_HMAC_SHA256
+#if GNULIB_GC_HMAC_SHA256
 Gc_rc
 gc_hmac_sha256 (const void *key, size_t keylen,
                 const void *in, size_t inlen, char *resbuf)
@@ -913,7 +962,7 @@ gc_hmac_sha256 (const void *key, size_t keylen,
 }
 #endif
 
-#ifdef GNULIB_GC_HMAC_SHA512
+#if GNULIB_GC_HMAC_SHA512
 Gc_rc
 gc_hmac_sha512 (const void *key, size_t keylen,
                 const void *in, size_t inlen, char *resbuf)
