@@ -70,7 +70,7 @@ extern "C"
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "2.6.6"
+#define OATH_VERSION "2.6.7"
 
 /**
  * OATH_VERSION_NUMBER
@@ -80,7 +80,7 @@ extern "C"
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x02060600
+#define OATH_VERSION_NUMBER 0x02060700
 
 /**
  * oath_rc:
@@ -110,6 +110,8 @@ extern "C"
  * @OATH_FILE_FLUSH_ERROR: System error when flushing file buffer
  * @OATH_FILE_SYNC_ERROR: System error when syncing file to disk
  * @OATH_FILE_CLOSE_ERROR: System error when closing file
+ * @OATH_FILE_CHOWN_ERROR: System error when changing file ownership
+ * @OATH_FILE_STAT_ERROR: System error when getting file status
  * @OATH_LAST_ERROR: Meta-error indicating the last error code, for use
  *   when iterating over all error codes or similar.
  *
@@ -148,9 +150,11 @@ typedef enum
   OATH_FILE_FLUSH_ERROR = -23,
   OATH_FILE_SYNC_ERROR = -24,
   OATH_FILE_CLOSE_ERROR = -25,
+  OATH_FILE_CHOWN_ERROR = -26,
+  OATH_FILE_STAT_ERROR = -27,
   /* When adding anything here, update OATH_LAST_ERROR, errors.c
      and tests/tst_errors.c. */
-  OATH_LAST_ERROR = -25
+  OATH_LAST_ERROR = -27
 } oath_rc;
 
 /* Global */
