@@ -381,6 +381,17 @@ update_usersfile (const char *usersfile,
   rc = update_usersfile2 (username, otp, infh, outfh, lineptr, n,
 			  timestamp, new_moving_factor, skipped_users);
 
+  /* Preserve ownership of the new usersfile file */
+  {
+    struct stat insb;
+
+    if(rc == OATH_OK && fstat(fileno(infh), &insb) == -1)
+      rc = OATH_FILE_STAT_ERROR;
+
+    if(rc == OATH_OK && fchown(fileno(outfh), insb.st_uid, insb.st_gid) != 0)
+      rc = OATH_FILE_CHOWN_ERROR;
+  }
+
   /* On success, flush the buffers. */
   if (rc == OATH_OK && fflush (outfh) != 0)
     rc = OATH_FILE_FLUSH_ERROR;
