@@ -26,6 +26,8 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
+#include <pwd.h>
+#include <unistd.h>
 
 /* Libtool defines PIC for shared objects */
 #ifndef PIC
@@ -41,6 +43,9 @@
 #ifdef HAVE_SECURITY_PAM_APPL_H
 #include <security/pam_appl.h>
 #endif
+#ifdef HAVE_SECURITY_PAM_MODUTIL_H
+#include <security/pam_modutil.h>
+#endif
 #ifdef HAVE_SECURITY_PAM_MODULES_H
 #include <security/pam_modules.h>
 #endif
@@ -129,6 +134,110 @@ parse_cfg (int flags, int argc, const char **argv, struct cfg *cfg)
     }
 }
 
+static int
+parse_usersfile_str(pam_handle_t * pamh, const struct cfg *cfg, const char *user, char **usersfile)
+{
+  int retval = PAM_SUCCESS;
+  size_t name_len = 0;
+  size_t home_len = 0;
+  size_t len = strlen(cfg->usersfile) + 1;
+  char *str = NULL;
+  char *u = NULL;
+  struct passwd *pw = NULL;
+
+  if(*usersfile) {
+    return PAM_BUF_ERR;
+  }
+
+  pw = pam_modutil_getpwnam(pamh, user);
+  if(!pw)
+    {
+      return PAM_USER_UNKNOWN;
+    }
+
+  /*
+    Find occurances of the placeholder fields to determine
+    userfile buffer length
+  */
+  name_len = strlen(pw->pw_name);
+  home_len = strlen(pw->pw_dir);
+  str = cfg->usersfile;
+  while((str = strstr(str, "${USER}")))
+    {
+      len += name_len;
+      len -= 7;
+      str += 7;
+    }
+  str = cfg->usersfile;
+  while((str = strstr(str, "${HOME}")))
+    {
+      len += home_len;
+      len -= 7;
+      str += 7;
+    }
+
+  *usersfile = malloc(len);
+  if( !(*usersfile) )
+    {
+      return PAM_BUF_ERR;
+    }
+  memset(*usersfile, 0, len);
+
+  str = cfg->usersfile;
+  u   = *usersfile;
+  while(*str)
+    {
+      char *c = strchr(str, '$');
+      if(c)
+        {
+	  /* Copy all preceding characters */
+	  const size_t str_len = c - str;
+	  memcpy(u, str, str_len);
+	  u   += str_len;
+	  str += str_len;
+
+	  const char *rpl_str = NULL;
+	  size_t rpl_len = 0;
+
+	  if(strncmp(str, "${USER}", 7) == 0)
+	    {
+	      rpl_str = pw->pw_name;
+	      rpl_len = name_len;
+	      str += 7;
+	    }
+	  else if(strncmp(str, "${HOME}", 7) == 0)
+	    {
+	      rpl_str = pw->pw_dir;
+	      rpl_len = home_len;
+	      str += 7;
+	    }
+	  else
+	    {
+	      rpl_str = "$";
+	      rpl_len = 1;
+	      str += 1;
+	    }
+
+	  memcpy(u, rpl_str, rpl_len);
+	  u   += rpl_len;
+	}
+      else
+        {
+	  size_t str_len = strlen(str);
+	  memcpy(u, str, str_len);
+	  u   += str_len;
+	  str += str_len;
+	}
+    }
+done:
+  if(retval != PAM_SUCCESS)
+    {
+      free(*usersfile);
+      *usersfile = NULL;
+    }
+  return retval;
+}
+
 PAM_EXTERN int
 pam_sm_authenticate (pam_handle_t * pamh,
 		     int flags, int argc, const char **argv)
@@ -136,6 +245,7 @@ pam_sm_authenticate (pam_handle_t * pamh,
   int retval, rc;
   const char *user = NULL;
   const char *password = NULL;
+  char *usersfile = NULL;
   char otp[MAX_OTP_LEN + 1];
   int password_len = 0;
   struct pam_conv *conv;
@@ -164,13 +274,21 @@ pam_sm_authenticate (pam_handle_t * pamh,
     }
   DBG (("get user returned: %s", user));
 
+  retval = parse_usersfile_str(pamh, &cfg, user, &usersfile);
+  if(retval != PAM_SUCCESS)
+    {
+      DBG (("parse usersfile string returned error: %s", pam_strerror (pamh, retval)));
+      goto done;
+    }
+  DBG (("usersfile is %s", usersfile));
+
   // quick check to skip unconfigured users before prompting for password
   {
     time_t last_otp;
     otp[0] = '\0';
-    rc = oath_authenticate_usersfile (cfg.usersfile,
-				      user,
-				      otp, cfg.window, onlypasswd, &last_otp);
+    rc = oath_authenticate_usersfile (usersfile,
+                                      user,
+                                      otp, cfg.window, onlypasswd, &last_otp);
 
     DBG (("authenticate first pass rc %d (%s: %s) last otp %s", rc,
 	  oath_strerror_name (rc) ? oath_strerror_name (rc) : "UNKNOWN",
@@ -324,7 +442,7 @@ pam_sm_authenticate (pam_handle_t * pamh,
   {
     time_t last_otp;
 
-    rc = oath_authenticate_usersfile (cfg.usersfile,
+    rc = oath_authenticate_usersfile (usersfile,
 				      user,
 				      otp, cfg.window, onlypasswd, &last_otp);
     DBG (("authenticate rc %d (%s: %s) last otp %s", rc,
@@ -343,6 +461,7 @@ pam_sm_authenticate (pam_handle_t * pamh,
 
 done:
   oath_done ();
+  free (usersfile);
   free (query_prompt);
   free (onlypasswd);
   if (cfg.alwaysok && retval != PAM_SUCCESS)
